@@ -19,8 +19,12 @@
  *
  */
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 #include <errno.h>
 #include <time.h>
 #include <getopt.h>
@@ -28,13 +32,20 @@
 
 static int verbose = 0;
 
+/* mode codes for change_state() */
+#define SUSPEND 0
+#define STANDBY 1
+#define IGNORE 2
+#define NOIGNORE 3
+
 void change_state(int mode)
 {
     int fd;
     time_t then, now;
     int error;
 
-    if ((fd = apm_open()) < 0)
+    fd = open(APM_DEVICE, O_WRONLY);
+    if (fd < 0)
     {
 	fprintf(stderr, "Cannot open APM device: %s\n", strerror(errno));
 	exit(1);
@@ -71,8 +82,12 @@ void change_state(int mode)
 
 void usage(void)
 {
+    fprintf(stderr, "usage: apm [-VvmMsSd");
+#ifdef APM_IOC_IGNORE		/* detect kernel support of IGNORE/NOIGNORE functions */
+    fprintf(stderr, "in");
+#endif
     fprintf(stderr,
-	    "usage: apm [-vmMsSin] [--verbose] [--minutes] [--monitor] [--suspend] [--standby]");
+	    "] [--verbose] [--minutes] [--monitor] [--suspend] [--standby]");
 #ifdef APM_IOC_IGNORE		/* detect kernel support of IGNORE/NOIGNORE functions */
     fprintf(stderr, " [--ignore] [--noignore]");
 #endif
@@ -181,21 +196,21 @@ int main(int argc, char **argv)
 	printf("APM BIOS %d.%d (kernel driver %s)\n",
 	     i.apm_version_major, i.apm_version_minor, i.driver_version);
 
-	if (monitor)
+    if (monitor)
 	{
 		int secs, q = 0;
-		char battery[16], output[64] = "", buf[64] = "";
+		char battery[32], output[128] = "", buf[128] = "";
 		while(1) {
 			apm_read(&i);
 			secs = i.using_minutes ? i.battery_time * 60 : i.battery_time;
 			if(displayMinutes)
 				sprintf(battery, "%d min", secs / 60);
 			else
-				sprintf(battery, "%s", apm_time_nosec(secs));
-			sprintf(output, "AC: %s\nBattery: %d%% (%s)",
-					i.ac_line_status == 0 ? "off-line" : "on-line",
+				sprintf(battery, "%s", apm_time(secs));
+			sprintf(output, "Line   : %s \nBattery: %d%% (%s)      ",
+					i.ac_line_status == 0 ? "off" : "on ",
 					i.battery_percentage, battery);
-			if(q == 0 || strcmp(buf, output) < 0) {
+			if(q == 0 || !strcmp(buf, output)) {
 				printf("\e[H\e[J%s\n", output);
 				q = 1;
 			}
@@ -219,10 +234,10 @@ int main(int argc, char **argv)
     switch (i.ac_line_status)
     {
     case 0:
-	printf("AC off-line");
+	printf("Off-line");
 	break;
     case 1:
-	printf("AC on-line");
+	printf("On-line");
 	break;
     case 2:
 	printf("On backup power");
@@ -262,7 +277,7 @@ int main(int argc, char **argv)
 	    if (displayMinutes)
 		printf(" (%d min)", secs / 60);
 	    else
-		printf(" (%s)", apm_time_nosec(secs));
+		printf(" (%s)", apm_time(secs));
 	}
     }
     printf("\n");
@@ -271,11 +286,11 @@ int main(int argc, char **argv)
     {
 	printf("Using device 0x%04lx, %s: %d.%d\n", (unsigned long) apm_dev(),
 	     i.driver_version, i.apm_version_major, i.apm_version_minor);
-	printf("APM Flags =      0x%02x; AC Line Status = 0x%02x\n",
+	printf("APM Flags      = 0x%02x; Line Status   = 0x%02x\n",
 	       i.apm_flags, i.ac_line_status);
-	printf("Battery Status = 0x%02x; Battery Flags =  0x%02x\n",
+	printf("Battery Status = 0x%02x; Battery Flags = 0x%02x\n",
 	       i.battery_status, i.battery_flags);
-	printf("Battery %%age   = %4d; Battery Time   = %4d, use_mins=%d\n",
+	printf("Battery %%age   = %4d; Battery Time  = %4d, use_mins=%d\n",
 	       i.battery_percentage, i.battery_time, i.using_minutes);
     }
 
